searchData={"items":[{"type":"module","title":"Castle","doc":"Documentation for `Castle`.","ref":"Castle.html"},{"type":"function","title":"Castle.commit/1","doc":"","ref":"Castle.html#commit/1"},{"type":"function","title":"Castle.generate/1","doc":"","ref":"Castle.html#generate/1"},{"type":"function","title":"Castle.install/1","doc":"","ref":"Castle.html#install/1"},{"type":"function","title":"Castle.make_releases/0","doc":"","ref":"Castle.html#make_releases/0"},{"type":"function","title":"Castle.releases/0","doc":"","ref":"Castle.html#releases/0"},{"type":"function","title":"Castle.remove/1","doc":"","ref":"Castle.html#remove/1"},{"type":"function","title":"Castle.unpack/1","doc":"","ref":"Castle.html#unpack/1"},{"type":"extras","title":"Castle","doc":"# Castle\n\nRuntime support for hot-code upgrades.\n\n`Castle` provides runtime support for hot-code upgrades. In particular, it generates a \nvalid `sys.config` from `runtime.exs` and/or other [Config Providers](https://hexdocs.pm/elixir/main/Config.Provider.html)\nprior to both boot and hot-code upgrade.\n\nIt relies on [Forecastle](https://hexdocs.pm/forecastle/readme.html) for build-time release generation\nand brings it in as a build-time dependency.","ref":"readme.html"},{"type":"extras","title":"Installation - Castle","doc":"The package can be installed by adding `castle` to your list of dependencies in\n`mix.exs`. For projects that don't define a release, but use the `appup` compiler,\nit's sufficient to bring `Castle` in as a build-time dependency:\n\n```elixir\ndef deps do\n  [\n    {:castle, \"~> 0.3.0\", runtime: false}\n  ]\nend\n```\n\nFor projects that _do_ define one or more releases, `Castle` should be brought in\nas a runtime dependency:\n\n```elixir\ndef deps do\n  [\n    {:castle, \"~> 0.3.0\"}\n  ]\nend\n```\n\n`Castle` brings in `Forecastle` as a build-time dependency.","ref":"readme.html#installation"},{"type":"extras","title":"Integration - Castle","doc":"Build-time integration is done via `Forecastle` and more details can be found in its\ndocumentation but, in summary, it will integrate into your release process via the\nrelease assembly process. In particular, it requires that that the `Forecastle.pre_assemble/1` \nand `Forecastle.post_assemble/1` functions are placed around the `:assemble` step, e.g.:\n\n```elixir\ndefp releases do\n  [\n    myapp: [\n      include_executables_for: [:unix],\n      steps: [&Forecastle.pre_assemble/1, :assemble, &Forecastle.post_assemble/1, :tar]\n    ]\n  ]\nend\n```","ref":"readme.html#integration"},{"type":"extras","title":"Release Management - Castle","doc":"The script in the `bin` folder supports some extra commands to manage upgrades.\nReleases, in their tarred-gzipped form, should first be copied to the `releases`\nsubfolder on the target system. The following commands can be used to manage\nthem:\n\n  - `releases` - Lists the releases on the system and their status. Status can\n    be one of the following:\n    - permanent - the release the system will boot into on next restart.\n    - current - if it exists, represents the current running release. Will be\n      different from the permanent version if a new release has been installed\n      but not yet committed. If no version is listed as current, the permanent\n      version is the currently running version.\n    - old - if it exists, a previously installed version.\n    - unpacked - an unpacked version, but not yet installed.\n  - `unpack  ` - Unpacks the release called ` - .tar.gz`.\n  - `install  ` - Installs the new release. This makes the release the\n    current one, but not yet the permanent one. Prior to running the relup,\n    `Castle` generates the version specific `sys.config` for the new version.\n  - `commit  ` - Makes the specified release the one the permanent one.\n  - `remove  ` - Remove an old version from the filesystem. Any files\n    shared with remaining releases are left untouched.","ref":"readme.html#release-management"},{"type":"extras","title":"The Appup Compiler - Castle","doc":"You are responsible for writing the [appup](https://www.erlang.org/doc/man/appup.html)\nscripts for your application, but `Castle` will copy the appup into the `ebin` folder\nfor you. The steps are as follows:\n\n1. Write a file, in _Elixir form_, describing the application upgrade. e.g.:\n   ```elixir\n   # You can call the file what you like, e.g. appup.ex, \n   # but you should # keep it away from the compiler paths.\n   {\n    '0.1.1',\n     [\n      {'0.1.0', [\n        {:update, MyApp.Server, {:advanced, []}}\n      ]}\n     ],\n     [\n      {'0.1.0', [\n        {:update, MyApp.Server, {:advanced, []}}\n      ]}\n     ]\n   }\n   ```\n   This file will typically be checked in to SCM.\n2. Add the appup file to the Mix project definition in mix.exs and add the\n   `:appup` compiler.\n   ```elixir\n   # Mix.exs\n   def project do\n     [\n       appup: \"appup.ex\", # Relative to the project root.\n       compilers: Mix.compilers() ++ [:appup]\n     ]\n   end\n   ```","ref":"readme.html#the-appup-compiler"},{"type":"extras","title":"Relup Generation - Castle","doc":"Castle contains a mix task, `castle.relup`, that simplifies the generation of\nthe relup file. Assuming you have two _unpacked_ releases e.g. `0.1.0` and `0.1.1` \nand you wish to generate a relup between them:\n\n```shell\n> mix castle.relup --target myapp/releases/0.1.1/myapp --fromto myapp/releases/0.1.0/myapp\n```\n\nIf the generated file is in the project root, it will be copied during \npost-assembly to the release.","ref":"readme.html#relup-generation"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.3.1 - Jan 19, 2025 - Changelog","doc":"- Switch to charlist sigils","ref":"changelog.html#0-3-1-jan-19-2025"},{"type":"extras","title":"0.3.0 - May 27, 2023 - Changelog","doc":"- Move build time support into Forecastle","ref":"changelog.html#0-3-0-may-27-2023"},{"type":"extras","title":"0.2.3 - May 21, 2023 - Changelog","doc":"- Fix bug in shell script that prevented execution on Linux","ref":"changelog.html#0-2-3-may-21-2023"},{"type":"extras","title":"0.2.2 - May 21, 2023 - Changelog","doc":"- Update Changelog","ref":"changelog.html#0-2-2-may-21-2023"},{"type":"extras","title":"0.2.1 - May 21, 2023 - Changelog","doc":"- Update README","ref":"changelog.html#0-2-1-may-21-2023"},{"type":"extras","title":"0.2.0 - May 21, 2023 - Changelog","doc":"- Added support for Config Provider expansion","ref":"changelog.html#0-2-0-may-21-2023"},{"type":"extras","title":"0.1.3 - May 16, 2023 - Changelog","doc":"- Initial revision","ref":"changelog.html#0-1-3-may-16-2023"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}